@@ -22,7 +22,7 @@ parents.lvm <- function(object,var,...) {
   if (missing(var)) {
     return(rownames(A))
   }
-  if (class(var)[1]=="formula")
+  if (inherits(var,"formula"))
     var <- all.vars(var)
   res <- lapply(var, function(v) rownames(A)[A[,v]!=0])
   unique(unlist(res))
@@ -34,7 +34,7 @@ children.lvm <- function(object,var,...) {
   if (missing(var)) {
     return(rownames(A))
   }
-  if (class(var)[1]=="formula")
+  if (inherits(var,"formula"))
     var <- all.vars(var)
   res <- lapply(var, function(v) rownames(A)[A[v,]!=0])
   unique(unlist(res))
